"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const notifiable_1 = require("../notifications/notifiable");
const notification_1 = require("../notifications/notification");
class CreditCardValidationContract extends notifiable_1.Notifiable {
    creditCardDateIsValid(val, property, message) {
        const patternDate = /^\d{1,2}\/\d{4}$/;
        if (!patternDate.test(val)) {
            this.addNotification(new notification_1.Notification(property, message));
        }
        return this;
    }
    creditCardNumberIsValid(val, property, message) {
        // accept only digits, dashes or spaces
        if (/[^0-9-\s]+/.test(val)) {
            return false;
        }
        // The Luhn Algorithm. It's so pretty.
        let nCheck = 0;
        let nDigit = 0;
        let bEven = false;
        val = val.replace(/\D/g, "");
        for (let n = val.length - 1; n >= 0; n--) {
            const cDigit = val.charAt(n);
            nDigit = parseInt(cDigit, 10);
            if (bEven) {
                // tslint:disable-next-line:no-conditional-assignment
                if ((nDigit *= 2) > 9) {
                    nDigit -= 9;
                }
            }
            nCheck += nDigit;
            bEven = !bEven;
        }
        if (!((nCheck % 10) === 0)) {
            this.addNotification(new notification_1.Notification(property, message));
        }
        return this;
    }
    creditCardDateIsGreaterThanToday(val, property, message) {
        const patternDate = /^\d{1,2}\/\d{4}$/;
        if (!patternDate.test(val)) {
            this.addNotification(new notification_1.Notification(property, message));
            return this;
        }
        const today = new Date();
        const someday = new Date();
        const date = val.split("/");
        someday.setFullYear(parseInt(date[1], 10), parseInt(date[0], 10), 1);
        if (someday < today) {
            this.addNotification(new notification_1.Notification(property, message));
        }
        return this;
    }
}
exports.CreditCardValidationContract = CreditCardValidationContract;
